@@ -9,8 +9,8 @@
 enum { 
   APP_BP_TIME_STAMP = END_OF_SPS, APP_BP_SHOW_TOOLBAR,
   APP_BP_SHOW_TOOLBAR_TEXT, APP_BP_SHOW_LARGE_ICONS, APP_BP_FIX_LAYOUT,
-  APP_BP_COPY_ALL_ON_STOP,APP_BP_WINDOW_PAUSE,APP_BP_SPEECH_MODE, 
-  APP_BP_KEYBOARD_MODE, APP_BP_DOCK, END_OF_APP_BPS
+  APP_BP_COPY_ALL_ON_STOP,APP_BP_WINDOW_PAUSE, APP_BP_SPEECH_MODE, 
+  APP_BP_KEYBOARD_MODE, APP_BP_DOCK, APP_BP_SPEECH_WORD, END_OF_APP_BPS
 };
 
 enum { 
@@ -32,4 +32,9 @@ enum {
   END_OF_APP_SPS
 };
 
+enum {
+  APP_STYLE_TRAD = 0,
+  APP_STYLE_COMPOSE,
+  APP_STYLE_DIRECT,
+  APP_STYLE_FULLSCREEN };
 #endif
