@@ -145,9 +145,25 @@ void CAlphIO::SetInfo(const AlphInfo &NewInfo) {
   Save(NewInfo.AlphID);
 }
 
+void CAlphIO::DeleteGroups(SGroupInfo *Info) {
+  SGroupInfo *next;
+
+  while (Info) {
+    next = Info->pNext;
+
+    if (Info->pChild)
+      DeleteGroups(Info->pChild);
+
+    delete Info;
+    Info = next;
+  }
+}
+
 void CAlphIO::Delete(const std::string &AlphID) {
-  if(Alphabets.find(AlphID) != Alphabets.end()) {
-    Alphabets.erase(AlphID);
+  map<std::string, AlphInfo>::iterator it = Alphabets.find(AlphID);
+  if(it != Alphabets.end()) {
+    DeleteGroups(it->second.m_pBaseGroup);
+    Alphabets.erase(it);
     Save("");
   }
 }
@@ -402,7 +418,6 @@ void CAlphIO::XML_StartElement(void *userData, const XML_Char *name, const XML_C
     Me->InputInfo.ControlCharacter.Colour = -1;
     Me->InputInfo.StartConvertCharacter.Text = "";
     Me->InputInfo.EndConvertCharacter.Text = "";
-    Me->InputInfo.ResetCharacter.Text = "";
     Me->InputInfo.m_iCharacters = 1; // Start at 1 as 0 is the root node symbol
     Me->InputInfo.m_pBaseGroup = 0;
     Me->bFirstGroup = true;
@@ -663,20 +678,6 @@ void CAlphIO::XML_StartElement(void *userData, const XML_Char *name, const XML_C
     return;
   }
 
-  if(strcmp(name, "reset") == 0) {
-    while(*atts != 0) {
-      if(strcmp(*atts, "t") == 0) {
-        atts++;
-        Me->InputInfo.ResetCharacter.Text = *atts;
-	Me->InputInfo.ResetCharacter.Display = "";
-	Me->InputInfo.ResetCharacter.Colour = 0;
-	Me->InputInfo.ResetCharacter.Foreground = "";
-        atts--;
-      }
-      atts += 2;
-    }
-    return;
-  }
 
   if(strcmp(name, "context") == 0) {
     while(*atts != 0) {
@@ -769,3 +770,8 @@ void CAlphIO::XML_CharacterData(void *userData, const XML_Char *s, int len) {
 
   Me->CData.append(s, len);
 }
+
+CAlphIO::~CAlphIO() {
+  for (std::map<std::string, AlphInfo>::iterator it = Alphabets.begin(); it != Alphabets.end(); ++it)
+    DeleteGroups(it->second.m_pBaseGroup);
+}
