@@ -1,24 +1,48 @@
 // DasherInterfaceBase.h
 //
-// Copyright (c) 2002 Iain Murray
+// Copyright (c) 2007 The Dasher Team
+//
+// This file is part of Dasher.
+//
+// Dasher is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+//
+// Dasher is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Dasher; if not, write to the Free Software 
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 #ifndef __DasherInterfaceBase_h__
 #define __DasherInterfaceBase_h__
 
+///
+/// \mainpage 
+///
+/// This is the Dasher source code documentation. Please try to keep
+/// it up to date!
+///
+
 // TODO - there is a list of things to be configurable in my notes
 // Check that everything that is not self-contained within the GUI is covered.
 
 #include "../Common/NoClones.h"
 #include "../Common/ModuleSettings.h"
+#include "ActionButton.h"
 #include "Alphabet/Alphabet.h"
 #include "Alphabet/AlphIO.h"
-#include "ColourIO.h"
-#include "ModuleManager.h"
-#include "ActionButton.h"
-
 #include "AutoSpeedControl.h"
-
+#include "ColourIO.h"
 #include "InputFilter.h"
+#include "ModuleManager.h"
+
+#include <map>
+#include <algorithm>
 
 namespace Dasher {
   class CDasherScreen;
@@ -27,34 +51,32 @@ namespace Dasher {
   class CDasherModel;
   class CEventHandler;
   class CEvent;
-}
-
-class Dasher::CDasherScreen;
-class Dasher::CDasherView;
-class Dasher::CDasherInput;
-class Dasher::CDasherModel;
-class Dasher::CEventHandler;
-class Dasher::CEvent;
-class CSettingsStore;
-class CUserLogBase;
-class CDasherButtons;
-class CNodeCreationManager;
-
-#include <map>
-#include <algorithm>
-
-namespace Dasher {
+  
   class CDasherInterfaceBase;
 }
+
+class CSettingsStore;
+class CUserLogBase;
+class CNodeCreationManager;
+
+/// \defgroup Core Core Dasher classes
+/// @{
+
+
+struct Dasher::SLockData {
+  std::string strDisplay;
+  int iPercent;
+};
+
+
 /// The central class in the core of Dasher. Ties together the rest of
 /// the platform independent stuff and provides a single interface for
 /// the UI to use.
-
 class Dasher::CDasherInterfaceBase:private NoClones
 {
 public:
   CDasherInterfaceBase();
-  virtual ~ CDasherInterfaceBase();
+  virtual ~CDasherInterfaceBase();
 
   /// @name Access to internal member classes
   /// Access various classes contained within the interface. These
@@ -154,10 +176,6 @@ public:
 
   void ResetParameter(int iParmater);
   
-  /// \todo Document this
-
-  void GetFontSizes(std::vector < int >*FontSizes) const;
-
   ///
   /// Obtain the permitted values for a string parameter - used to
   /// geneate preferences dialogues etc.
@@ -192,12 +210,6 @@ public:
   void PreSetNotify(int iParameter, const std::string &sValue);
 
 
-  /// Draw a new Dasher frame, regardless of whether we're paused etc.
-  /// \param iTime Current time in ms.
-  /// \todo See comments in cpp file for some functionality which needs to be re-implemented
-
-  void NewFrame(unsigned long iTime, bool bForceRedraw);
-
 
   /// @name Starting and stopping
   /// Methods used to instruct dynamic motion of Dasher to start or stop
@@ -239,9 +251,11 @@ public:
   void ChangeScreen(CDasherScreen * NewScreen); // We may change the widgets Dasher uses
 
   /// Train Dasher from a file
+  /// All traing data must be in UTF-8
   /// \param Filename File to load.
-
-  int TrainFile(std::string Filename, int iTotalBytes, int iOffset); // all training data must be in UTF-8.
+  /// \param iTotalBytes documentme
+  /// \param iOffset Document me
+  //  int TrainFile(std::string Filename, int iTotalBytes, int iOffset);
 
   /// Set the context in which Dasher makes predictions
   /// \param strNewContext The new context (UTF-8)
@@ -310,9 +324,9 @@ public:
   /// Deals with forwarding user input to the core
   /// @{
 
-  void KeyDown(int iTime, int iId);
+  void KeyDown(int iTime, int iId, bool bPos = false, int iX = 0, int iY = 0);
 
-  void KeyUp(int iTime, int iId);
+  void KeyUp(int iTime, int iId, bool bPos = false, int iX = 0, int iY = 0);
 
   void HandleClickUp(int iTime, int iX, int iY);
 
@@ -333,14 +347,26 @@ public:
     //    Start();
   };
 
-  void ScheduleRedraw() {
-    m_bRedrawScheduled = true;
-  };
+  void GameMessageIn(int message, void* messagedata);
+
+  virtual void GameMessageOut(int message, const void* messagedata) {}
+
+  void ScheduleRedraw() { 
+    m_bRedrawScheduled = true; 
+  }; 
 
   void CheckRedraw();
 
   std::string GetContext(int iStart, int iLength);
 
+  void SetControlOffset(int iOffset);
+
+  /// Set a key value pair by name - designed to allow operation from
+  /// the command line
+  ///
+  void ClSet(const std::string &strKey, const std::string &strValue);
+
+  void ImportTrainingText(const std::string &strPath);
 
 protected:
 
@@ -364,6 +390,15 @@ protected:
 
   /// @}
 
+
+
+  /// Draw a new Dasher frame, regardless of whether we're paused etc.
+  /// \param iTime Current time in ms.
+  /// \param bForceRedraw 
+  /// \todo See comments in cpp file for some functionality which needs to be re-implemented
+  void NewFrame(unsigned long iTime, bool bForceRedraw);
+
+
   enum ETransition {
     TR_MODEL_INIT = 0,
     TR_UI_INIT,
@@ -393,7 +428,7 @@ protected:
 
   /// @}
 
-  CDasherModule *GetModule(long long int iID);
+  CDasherModule *GetModule(ModuleID_t iID);
   CDasherModule *GetModuleByName(const std::string &strName);
 
   CEventHandler *m_pEventHandler;
@@ -519,15 +554,20 @@ protected:
   /// Add a lock
   ///
 
-  void AddLock(int iLockFlags);
+  int AddLock(const std::string &strDisplay);
 
   ///
   /// Release an existing lock. Note that these functions have minimal
   /// error checking at the moment, so be careful.
   ///
 
-  void ReleaseLock(int iLockFlags);
+  void ReleaseLock(int iLockID);
 
+  ///
+  /// Return the lock to display, or NULL for no locks present
+  ///
+
+  SLockData *GetCurrentLock(); 
   /// @}
   
   std::deque<std::string> m_deGameModeStrings;
@@ -550,6 +590,7 @@ protected:
   CUserLogBase *m_pUserLog; 
   CInputFilter* m_pInputFilter;
   CModuleManager m_oModuleManager;
+  //  CTrainingHelper *m_pTrainingHelper;
   /// @}
 
   std::string strTrainfileBuffer;
@@ -560,14 +601,19 @@ protected:
   /// @name State variables
   /// Represent the current overall state of the core
   /// @{
-  bool m_bGlobalLock; // The big lock
+  //  bool m_bGlobalLock; // The big lock
   bool m_bRedrawScheduled;
   int m_iLockCount;
   EState m_iCurrentState;
   bool m_bOldVisible;
+
+  std::map<int, SLockData> m_mapCurrentLocks;
+  int m_iNextLockID;
+
   /// @}
 
   bool m_bLastChanged;
 };
+/// @}
 
 #endif /* #ifndef __DasherInterfaceBase_h__ */
