@@ -1,20 +1,31 @@
 // DasherView.cpp
 //
-/////////////////////////////////////////////////////////////////////////////
+// Copyright (c) 2007 The Dasher Team
 //
-// Copyright (c) 2001-2005 David Ward
+// This file is part of Dasher.
 //
-/////////////////////////////////////////////////////////////////////////////
+// Dasher is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+//
+// Dasher is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Dasher; if not, write to the Free Software 
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 #include "../Common/Common.h"
 
+#include "DasherGameMode.h"
+#include "DasherInput.h"
+#include "DasherModel.h"
 #include "DasherView.h"
 #include "Event.h"
 #include "EventHandler.h"
-#include "DasherModel.h"
-#include "DasherInput.h"
-
-#include <iostream>
 
 using namespace Dasher;
 
@@ -31,7 +42,8 @@ static char THIS_FILE[] = __FILE__;
 /////////////////////////////////////////////////////////////////////////////
 
 CDasherView::CDasherView(CEventHandler *pEventHandler, CSettingsStore *pSettingsStore, CDasherScreen *DasherScreen)
-:CDasherComponent(pEventHandler, pSettingsStore), m_pScreen(DasherScreen), m_pInput(0) {
+  :CDasherComponent(pEventHandler, pSettingsStore), m_pScreen(DasherScreen), m_pInput(0),
+   m_bDemoMode(false), m_bGameMode(false) {
 }
 
 void CDasherView::HandleEvent(Dasher::CEvent *pEvent) {
@@ -56,15 +68,17 @@ void CDasherView::ChangeScreen(CDasherScreen *NewScreen) {
 
 /////////////////////////////////////////////////////////////////////////////
 
-bool CDasherView::Render(CDasherNode *pRoot, myint iRootMin, myint iRootMax, std::vector<CDasherNode *> &vNodeList, std::vector<CDasherNode *> &vDeleteList, bool bRedrawDisplay, bool bGameMode) {
+void CDasherView::RenderModel(CDasherModel *pModel) {
+  if(pModel)
+    pModel->RenderToView(this, true, NULL);
+}
+
+
+bool CDasherView::Render(CDasherNode *pRoot, myint iRootMin, myint iRootMax, std::vector<CDasherNode *> &vNodeList, std::vector<CDasherNode *> &vDeleteList, bool bRedrawDisplay, std::vector<std::pair<myint,bool> >* pvGameTargetY) {
 
   m_iRenderCount = 0;
-  myint iGamePointer;
   Screen()->SetLoadBackground(false);
-  RenderNodes(pRoot, iRootMin, iRootMax, vNodeList, vDeleteList, &iGamePointer);
-
-  if(bGameMode)
-    DrawGameModePointer(iGamePointer);
+  RenderNodes(pRoot, iRootMin, iRootMax, vNodeList, vDeleteList, pvGameTargetY);
 
   return true;
 }
@@ -130,6 +144,33 @@ void CDasherView::DasherPolyline(myint *x, myint *y, int n, int iWidth, int iCol
   delete[]ScreenPoints;
 }
 
+// Draw a polyline with an arrow on the end
+void CDasherView::DasherPolyarrow(myint *x, myint *y, int n, int iWidth, int iColour, double dArrowSizeFactor) {
+
+  CDasherScreen::point * ScreenPoints = new CDasherScreen::point[n+3];
+
+  for(int i(0); i < n; ++i)
+    Dasher2Screen(x[i], y[i], ScreenPoints[i].x, ScreenPoints[i].y);
+
+  int iXvec = (ScreenPoints[n-2].x - ScreenPoints[n-1].x)*dArrowSizeFactor;
+  int iYvec = (ScreenPoints[n-2].y - ScreenPoints[n-1].y)*dArrowSizeFactor;
+
+  ScreenPoints[n].x   = ScreenPoints[n-1].x + iXvec + iYvec;
+  ScreenPoints[n].y   = ScreenPoints[n-1].y - iXvec + iYvec;
+  ScreenPoints[n+1].x = ScreenPoints[n-1].x ;
+  ScreenPoints[n+1].y = ScreenPoints[n-1].y ;
+  ScreenPoints[n+2].x = ScreenPoints[n-1].x + iXvec - iYvec;
+  ScreenPoints[n+2].y = ScreenPoints[n-1].y + iXvec + iYvec;
+
+  if(iColour != -1) {
+    Screen()->Polyline(ScreenPoints, n+3, iWidth, iColour);
+  }
+  else {
+    Screen()->Polyline(ScreenPoints, n+3, iWidth,0);//no color given
+  }
+  delete[]ScreenPoints;
+}
+
 // Draw a filled polygon specified in Dasher co-ordinates
 
 void CDasherView::DasherPolygon(myint *x, myint *y, int n, int iColour) {
@@ -146,9 +187,6 @@ void CDasherView::DasherPolygon(myint *x, myint *y, int n, int iColour) {
 // Draw a box specified in Dasher co-ordinates
 
 void CDasherView::DasherDrawRectangle(myint iLeft, myint iTop, myint iRight, myint iBottom, const int Color, int iOutlineColour, Opts::ColorSchemes ColorScheme, bool bDrawOutline, bool bFill, int iThickness) {
-
-  //  std::cout << "Drawing rectangle: (" << iLeft << ", " << iTop << ") - (" << iRight << ", " << iBottom << ")" << std::endl;
-
   screenint iScreenLeft;
   screenint iScreenTop;
   screenint iScreenRight;
@@ -163,7 +201,6 @@ void CDasherView::DasherDrawRectangle(myint iLeft, myint iTop, myint iRight, myi
 /// Draw a rectangle centred on a given dasher co-ordinate, but with a size specified in screen co-ordinates (used for drawing the mouse blob)
 
 void CDasherView::DasherDrawCentredRectangle(myint iDasherX, myint iDasherY, screenint iSize, const int Color, Opts::ColorSchemes ColorScheme, bool bDrawOutline) {
-
   screenint iScreenX;
   screenint iScreenY;
 
@@ -294,15 +331,24 @@ void CDasherView::DasherDrawText(myint iAnchorX1, myint iAnchorY1, myint iAnchor
 }
 
 
-int CDasherView::GetCoordinates(unsigned long Time, myint &iDasherX, myint &iDasherY) {
+
+void CDasherView::DrawText(const std::string & str, myint x, myint y, int Size) {
+  screenint X, Y;
+  Dasher2Screen(x, y, X, Y);
+  
+  Screen()->DrawString(str, X, Y, Size);
+}
+
+
+int CDasherView::GetCoordinates(myint &iDasherX, myint &iDasherY) {
+
 
   // FIXME - Actually turn autocalibration on and off!
   // FIXME - AutoCalibrate should use Dasher co-ordinates, not raw mouse co-ordinates?
   // FIXME - Have I broken this by moving it before the offset is applied?
   // FIXME - put ymap stuff back in 
   // FIXME - optimise this
-  // TODO: Time isn't used!
-
+  
   int iCoordinateCount(GetCoordinateCount());
 
   myint *pCoordinates(new myint[iCoordinateCount]);
@@ -341,6 +387,25 @@ int CDasherView::GetCoordinates(unsigned long Time, myint &iDasherX, myint &iDas
   //  iDasherX = myint(xmap(iDasherX / static_cast < double >(GetLongParameter(LP_MAX_Y))) * GetLongParameter(LP_MAX_Y));
   // iDasherY = m_ymap.map(iDasherY);
 #endif
-
+  ///GAME///
+  if(m_bGameMode)
+    {
+      using GameMode::CDasherGameMode;
+      if(m_bDemoMode)
+        CDasherGameMode::GetTeacher()->DemoModeGetCoordinates(iDasherX, iDasherY);
+      CDasherGameMode::GetTeacher()->SetUserMouseCoordinates(iDasherX, iDasherY);
+    }
+      
   return iType;
 }
+
+
+void CDasherView::SetDemoMode(bool bDemoMode)
+{
+  m_bDemoMode = bDemoMode;
+}
+
+void CDasherView::SetGameMode(bool bGameMode)
+{
+  m_bGameMode = bGameMode;
+}
