@@ -3,10 +3,14 @@
 
 #include "DefaultFilter.h"
 
+/// \ingroup InputFilter
+/// @{
 class CEyetrackerFilter : public CDefaultFilter {
  public:
   CEyetrackerFilter(Dasher::CEventHandler * pEventHandler, CSettingsStore *pSettingsStore, CDasherInterfaceBase *pInterface, CDasherModel *m_pDasherModel);
 
+  bool GetSettings(SModuleSettings **pSettings, int *iCount);
+
  private:
   virtual void ApplyAutoCalibration(myint &iDasherX, myint &iDasherY, bool bUpdate);
   virtual void ApplyTransform(myint &iDasherX, myint &iDasherY);
@@ -20,5 +24,6 @@ class CEyetrackerFilter : public CDefaultFilter {
   int m_iCounter;
   int m_iFilterTimescale;
 };
+/// @}
 
 #endif
