@@ -9,7 +9,7 @@
 #ifndef __LanguageModelling_SymbolAlphabet_h__
 #define __LanguageModelling_SymbolAlphabet_h__
 
-#include "../Alphabet/Alphabet.h"
+//#include "../Alphabet/Alphabet.h"
 
 /////////////////////////////////////////////////////////////////////////////
 //
@@ -29,6 +29,10 @@
 
 namespace Dasher {
 
+  class CAlphabet;
+  /// \ingroup LM
+  /// @{
+
   class CSymbolAlphabet {
   public:
 
@@ -71,6 +75,8 @@ namespace Dasher {
     const CAlphabet *AlphabetPointer;
   };
 
+  /// @}
+
 }
 
 #endif // ndef __LanguageModelling_SymbolAlphabet_h__
