@@ -74,8 +74,13 @@ CCanvas::~CCanvas() {
 
 #if WITH_CAIRO
   cr = NULL;
+  cairo_surface_destroy(m_pDisplaySurface);
+  cairo_surface_destroy(m_pDecorationSurface);
+  cairo_surface_destroy(m_pOnscreenSurface);  
   cairo_destroy(display_cr);
   cairo_destroy(decoration_cr);
+  cairo_destroy(onscreen_cr);
+  cairo_destroy(widget_cr);
 #else
   g_object_unref(m_pDummyBuffer);
   g_object_unref(m_pDisplayBuffer);
@@ -83,6 +88,7 @@ CCanvas::~CCanvas() {
   g_object_unref(m_pOnscreenBuffer);
 #endif
 
+  delete[] cairo_colours;
   delete m_pPangoInk;
 }
 
@@ -232,21 +238,25 @@ void CCanvas::DrawRectangle(int x1, int y1, int x2, int y2, int Color, int iOutl
 #endif
   }
   
-//   if(bDrawOutline) {
-//     if( iOutlineColour == -1 )
-//       SET_COLOR(3);
-//     else
-//       SET_COLOR(iOutlineColour);
+  if(bDrawOutline) {
+    if( iOutlineColour == -1 )
+      SET_COLOR(3);
+    else
+      SET_COLOR(iOutlineColour);
     
-// #if WITH_CAIRO
-//     cairo_set_line_width(cr, iThickness);
-//     cairo_rectangle(cr, iLeft + 0.5, iTop + 0.5, iWidth, iHeight);
-//     cairo_stroke(cr);
-// #else
-//     gdk_gc_set_line_attributes(graphics_context, iThickness, GDK_LINE_SOLID, GDK_CAP_ROUND, GDK_JOIN_ROUND );
-//     gdk_draw_rectangle(m_pOffscreenBuffer, graphics_context, FALSE, iLeft, iTop, iWidth, iHeight);
-// #endif
-//   }
+    // TODO: There's a known issue here when the start of one box and
+    // the end of the other map to the same pixel. This generally
+    // results in box outlines being truncated.
+
+#if WITH_CAIRO
+    cairo_set_line_width(cr, iThickness);
+    cairo_rectangle(cr, iLeft + 0.5, iTop + 0.5, iWidth, iHeight);
+    cairo_stroke(cr);
+#else
+    gdk_gc_set_line_attributes(graphics_context, iThickness, GDK_LINE_SOLID, GDK_CAP_ROUND, GDK_JOIN_ROUND );
+    gdk_draw_rectangle(m_pOffscreenBuffer, graphics_context, FALSE, iLeft, iTop, iWidth, iHeight);
+#endif
+  }
   END_DRAWING;
 }
 
@@ -410,6 +420,7 @@ void CCanvas::TextSize(const std::string &String, int *Width, int *Height, int s
 #else
   PangoLayout *pLayout(m_pPangoCache->GetLayout(GTK_WIDGET(m_pCanvas), String, size));
 #endif
+
   pango_layout_get_pixel_extents(pLayout, m_pPangoInk, NULL);
 
   *Width = m_pPangoInk->width;
