@@ -122,6 +122,7 @@ void CDasherControl::SetupPaths() {
 
   SetStringParameter(SP_SYSTEM_LOC, system_data_dir);
   SetStringParameter(SP_USER_LOC, user_data_dir);
+  delete[] user_data_dir;
 }
 
 void CDasherControl::CreateSettingsStore() {
@@ -228,8 +229,8 @@ void CDasherControl::SetFocus() {
   gtk_widget_grab_focus(m_pCanvas);
 }
 
-void CDasherControl::GameMessageOut(void* gameHelper, int message, const void* messagedata) {
-  gtk_dasher_control_game_messageout(m_pDasherControl, gameHelper, message, messagedata);
+void CDasherControl::GameMessageOut(int message, const void* messagedata) {
+  gtk_dasher_control_game_messageout(m_pDasherControl, message, messagedata);
 }
 
 GArray *CDasherControl::GetAllowedValues(int iParameter) {
@@ -259,10 +260,10 @@ void CDasherControl::RealizeCanvas(GtkWidget *pWidget) {
 
 void CDasherControl::StartTimer() {
   // Start the timer loops as everything is set up
-  // Aim for 20 frames per second
+  // Aim for 40 frames per second, computers are getting faster
 
   if(g_iTimeoutID == 0) {
-    g_iTimeoutID = g_timeout_add_full(G_PRIORITY_DEFAULT_IDLE, 50, timer_callback, this, NULL);
+    g_iTimeoutID = g_timeout_add_full(G_PRIORITY_DEFAULT_IDLE, 25, timer_callback, this, NULL);
     // TODO: Reimplement this (or at least reimplement some kind of status reporting)
     //g_timeout_add_full(G_PRIORITY_DEFAULT_IDLE, 5000, long_timer_callback, this, NULL);
   }
