@@ -116,17 +116,6 @@ public:
 
   GArray *GetAllowedValues(int iParameter);
 
-  /// 
-  /// Load a file and use to train the language model
-  /// \param filename The file to load.
-  ///
-
-  void Train(const gchar * filename) {
-    // TODO: Shouldn't call this directly - need a wrapper function which stats for filesize etc.
-    // Better - allow user to pass a vector of filenames
-    TrainFile(filename,0,0);
-  };
-
   ///
   /// Called by UI needs to signal a new user trial is starting.
   ///
@@ -156,7 +145,7 @@ private:
 
   void ExternalEventHandler(Dasher::CEvent *pEvent);
   
-  void GameMessageOut(void* gameHelper, int message, const void* messagedata);
+  void GameMessageOut(int message, const void* messagedata);
 
   ///
   /// Notification from CDasherInterface that a parameter has changed
