@@ -4,12 +4,12 @@
 #include <iostream>
 
 CPangoCache::CPangoCache(const std::string &strFontName) {
-  font = pango_font_description_new();
-  pango_font_description_set_family(font, strFontName.c_str());
+  font = pango_font_description_from_string(strFontName.c_str());
 }
 
 void CPangoCache::ChangeFont(const std::string &strFontName) {
-  pango_font_description_set_family(font, strFontName.c_str());
+  pango_font_description_free(font);
+  font = pango_font_description_from_string(strFontName.c_str());
 
   // FIXME - probably need to free the pango layouts, but I can't find a function to do this.
 
@@ -25,19 +25,21 @@ PangoLayout *CPangoCache::GetLayout(GtkWidget *pCanvas, std::string sDisplayText
   // Calculate the name of the pango layout in the cache - this
   // includes the display text and the size.
 
-  char buffer[128];             // FIXME - what if we exceed this?
+   char buffer[128];             // FIXME - what if we exceed this?
 
-  snprintf(buffer, 128, "%d_%s", iSize, sDisplayText.c_str());
+   snprintf(buffer, 128, "%d_%s", iSize, sDisplayText.c_str());
+//   //  std::stringstream sCacheName;
+//   //sCacheName << iSize << "_" << sDisplayText;
 
-  //  std::stringstream sCacheName;
-  //sCacheName << iSize << "_" << sDisplayText;
+   std::string sCacheName(buffer);
 
-  std::string sCacheName(buffer);
+  // TODO: This is blatantly not going to work for unicode
+   //  int iCacheIndex(iSize + 256 * sDisplayText[0]);
 
   // If we haven't got a cached pango layout for this string/size yet,
   // create a new one
 
-  std::map < std::string, PangoLayout * >::iterator it(oPangoCache.find(sCacheName));
+  std::map<std::string, PangoLayout *>::iterator it(oPangoCache.find(sCacheName));
 
   if(it != oPangoCache.end())
     return it->second;
@@ -57,4 +59,5 @@ PangoLayout *CPangoCache::GetLayout(GtkWidget *pCanvas, std::string sDisplayText
 
     return pNewPangoLayout;
   }
+  return 0;
 }
