@@ -27,7 +27,7 @@
 #include "dasher_internal_buffer.h"
 #include "dasher_lock_dialogue.h"
 #include "dasher_main.h"
-#include "game_mode_helper.h"
+//#include "game_mode_helper.h"
 
 // TODO: Maybe reimplement something along the lines of the following, which used to be in edit.cc
 
@@ -79,13 +79,15 @@ struct _DasherEditorInternalPrivate {
   GtkVBox *pActionPane;
   GtkClipboard *pTextClipboard;
   GtkClipboard *pPrimarySelection;
+  GtkTable *pGameGroup;
+  GtkLabel *pGameInfoLabel;
   EditorAction *pActionRing;
   EditorAction *pActionIter;
   gboolean bActionIterStarted;
   gint iNextActionID;
   IDasherBufferSet *pBufferSet;
   IDasherBufferSet *pExternalBuffer;
-  GameModeHelper *pGameModeHelper;
+  //  GameModeHelper *pGameModeHelper;
   GtkTextMark *pNewMark;
   DasherAppSettings *pAppSettings;
   gchar *szFilename;
@@ -248,7 +250,7 @@ dasher_editor_internal_init(DasherEditorInternal *pDasherControl) {
   pPrivate->pPrimarySelection = gtk_clipboard_get(GDK_SELECTION_PRIMARY);
   pPrivate->pActionRing = NULL;
   pPrivate->iNextActionID = 0;
-  pPrivate->pGameModeHelper = NULL;
+  //  pPrivate->pGameModeHelper = NULL;
   pPrivate->bFileModified = FALSE;
 }
 
@@ -349,6 +351,8 @@ dasher_editor_internal_initialise(DasherEditor *pSelf, DasherAppSettings *pAppSe
     dasher_editor_internal_generate_filename(pSelf);
     dasher_editor_internal_clear(pSelf, false);
   }
+  
+//  pPrivate->pGameModeHelper = GAME_MODE_HELPER(game_mode_helper_new(pGladeXML, (void*)pSelf));
 }
 
 static void 
@@ -391,6 +395,12 @@ dasher_editor_internal_clipboard(DasherEditor *pSelf, clipboard_action act) {
   delete end;
 }
 
+void dasher_editor_internal_cleartext(DasherEditorInternal *pSelf)
+{
+  dasher_editor_internal_clear((DasherEditor *)pSelf, true);
+
+}
+
 void 
 dasher_editor_internal_handle_stop(DasherEditor *pSelf) {
   DasherEditorInternalPrivate *pPrivate = DASHER_EDITOR_INTERNAL_GET_PRIVATE(pSelf);
@@ -629,8 +639,8 @@ dasher_editor_internal_output(DasherEditor *pSelf, const gchar *szText, int iOff
   if(pPrivate->pBufferSet)
     idasher_buffer_set_insert(pPrivate->pBufferSet, szText, iOffset);
 
-  if(pPrivate->pGameModeHelper)
-    game_mode_helper_output(pPrivate->pGameModeHelper, szText);
+//   if(pPrivate->pGameModeHelper)
+//     game_mode_helper_output(pPrivate->pGameModeHelper, szText);
 
   pPrivate->bFileModified = TRUE;
 }
@@ -642,8 +652,8 @@ dasher_editor_internal_delete(DasherEditor *pSelf, int iLength, int iOffset) {
   if(pPrivate->pBufferSet)
     idasher_buffer_set_delete(pPrivate->pBufferSet, iLength, iOffset);
 
-  if(pPrivate->pGameModeHelper)
-    game_mode_helper_delete(pPrivate->pGameModeHelper, iLength);
+//   if(pPrivate->pGameModeHelper)
+//     game_mode_helper_delete(pPrivate->pGameModeHelper, iLength);
 
   pPrivate->bFileModified = TRUE;
 }
@@ -923,7 +933,6 @@ dasher_editor_internal_command(DasherEditor *pSelf, const gchar *szCommand) {
     return TRUE;
   }
  
-
   /* TODO: We need a rethink here */
   const gchar *szForwardCommand = NULL;
   gint iSubCommand = 0;
@@ -1348,8 +1357,9 @@ static void
 dasher_editor_internal_command_save(DasherEditor *pSelf, gboolean bPrompt, gboolean bAppend) { 
   DasherEditorInternalPrivate *pPrivate = DASHER_EDITOR_INTERNAL_GET_PRIVATE(pSelf);
 
-  gchar *szFilename;
+  gchar *szFilename = NULL;
 
+  // Hmm... this makes no sense - surely this always evaluates to true?
   if(bPrompt || !szFilename) {
     GtkWidget *pTopLevel = gtk_widget_get_toplevel(GTK_WIDGET(pPrivate->pTextView));
     GtkWidget *filesel = gtk_file_chooser_dialog_new(_("Select File"), 
