@@ -11,6 +11,7 @@
 
 #ifndef _WIN32_WCE
 #include "Sockets/SocketInput.h"
+#include "BTSocketInput.h"
 #endif
 
 #include "Common/WinOptions.h"
@@ -29,6 +30,7 @@ using namespace WinUTF8;
 
 CONST UINT WM_DASHER_EVENT = RegisterWindowMessage(_WM_DASHER_EVENT);
 CONST UINT WM_DASHER_FOCUS = RegisterWindowMessage(_WM_DASHER_FOCUS);
+CONST UINT WM_DASHER_GAME_MESSAGE = RegisterWindowMessage(_WM_DASHER_GAME_MESSAGE);
 
 CDasher::CDasher(HWND Parent):m_hParent(Parent) {
   // This class will be a wrapper for the Dasher 'control' - think ActiveX
@@ -50,6 +52,7 @@ CDasher::~CDasher(void) {
 void CDasher::CreateLocalFactories() {
 #ifndef _WIN32_WCE
   RegisterFactory(new CWrapperFactory(m_pEventHandler, m_pSettingsStore, new CSocketInput(m_pEventHandler, m_pSettingsStore)));
+  RegisterFactory(new CWrapperFactory(m_pEventHandler, m_pSettingsStore, new CBTSocketInput(m_pEventHandler, m_pSettingsStore)));
 #endif
   RegisterFactory(new CWrapperFactory(m_pEventHandler, m_pSettingsStore, new CDasherMouseInput(m_pEventHandler, m_pSettingsStore, m_pCanvas->getwindow())));
 }
@@ -105,6 +108,11 @@ void Dasher::CDasher::ExternalEventHandler(CEvent* pEvent) {
   SendMessage(m_hParent, WM_DASHER_EVENT, 0, (LPARAM)pEvent);
 }
 
+void Dasher::CDasher::GameMessageOut(int message, const void *messagedata)
+{
+  SendMessage(m_hParent, WM_DASHER_GAME_MESSAGE, (WPARAM)message, (LPARAM)messagedata);
+}
+
 // Gets the size of the window in screen coordinates.  
 bool Dasher::CDasher::GetWindowSize(int* pTop, int* pLeft, int* pBottom, int* pRight) {
 	if ((pTop == NULL) || (pLeft == NULL) || (pBottom == NULL) || (pRight == NULL))
@@ -268,7 +276,8 @@ void CDasher::CreateSettingsStore(void) {
 
 void CDasher::StartTimer() {
   // TODO: See MessageLoop, Main in CDasherWindow - should be brought into this class
-  SetTimer(m_pCanvas->getwindow(), 1, 50, NULL);
+  // Framerate settings: currently 40fps.
+  SetTimer(m_pCanvas->getwindow(), 1, 25, NULL);
 }
 
 void CDasher::ShutdownTimer() {
