@@ -30,6 +30,7 @@
 
 #include "Widgets/Slidebar.h"
 #include "Widgets/Toolbar.h"
+#include "Widgets/GameGroup.h"
 #include "WinCommon.h"
 
 #ifndef _WIN32_WCE
@@ -50,9 +51,10 @@ using namespace std;
 CDasherWindow::CDasherWindow() {
   m_pToolbar = 0;
   m_pEdit = 0;
-  m_pSlidebar = 0;
+  m_pSpeedAlphabetBar = 0;
   m_pSplitter = 0;
   m_pDasher = 0;
+  m_pGameGroup = 0;
 
   m_hIconSm = (HICON) LoadImage(WinHelper::hInstApp, (LPCTSTR) IDI_DASHER, IMAGE_ICON, GetSystemMetrics(SM_CXSMICON), GetSystemMetrics(SM_CYSMICON), LR_DEFAULTCOLOR);
   
@@ -79,7 +81,7 @@ HWND CDasherWindow::Create() {
   HWND hWnd;
 
 #ifndef _WIN32_WCE
-  if((iStyle == 1) || (iStyle == 2))
+  if((iStyle == APP_STYLE_COMPOSE) || (iStyle == APP_STYLE_DIRECT))
     hWnd = CWindowImpl<CDasherWindow >::Create(NULL, NULL, WindowTitle.c_str(), WS_OVERLAPPEDWINDOW | WS_CLIPCHILDREN,  WS_EX_NOACTIVATE | WS_EX_APPWINDOW | WS_EX_TOPMOST);
   else
     hWnd = CWindowImpl<CDasherWindow >::Create(NULL, NULL, WindowTitle.c_str(), WS_OVERLAPPEDWINDOW | WS_CLIPCHILDREN);
@@ -97,7 +99,7 @@ HWND CDasherWindow::Create() {
   m_pEdit = new CEdit(m_pAppSettings);
   m_pEdit->Create(hWnd, m_pAppSettings->GetBoolParameter(APP_BP_TIME_STAMP));
   m_pEdit->SetFont(m_pAppSettings->GetStringParameter(APP_SP_EDIT_FONT), m_pAppSettings->GetLongParameter(APP_LP_EDIT_FONT_SIZE));
-
+ 
 #ifdef PJC_EXPERIMENTAL
   g_hWnd = m_pEdit->GetHwnd();
 #endif
@@ -113,9 +115,13 @@ HWND CDasherWindow::Create() {
 
   m_pEdit->SetInterface(m_pDasher);
 
-  m_pSlidebar = new CStatusControl(m_pDasher);
-  m_pSlidebar->Create(hWnd);
+  m_pSpeedAlphabetBar = new CStatusControl(m_pDasher);
+  m_pSpeedAlphabetBar->Create(hWnd);
 
+  m_pGameGroup = new CGameGroup(m_pDasher, m_pEdit);
+  m_pGameGroup->Create(hWnd);
+  m_pGameGroup->ShowWindow(SW_HIDE);
+  m_pGameGroup->SetEditFont(m_pAppSettings->GetStringParameter(APP_SP_EDIT_FONT), m_pAppSettings->GetLongParameter(APP_LP_EDIT_FONT_SIZE));
 
   m_pSplitter = new CSplitter(this,100);
   HWND hSplitter =  m_pSplitter->Create(hWnd);
@@ -164,13 +170,13 @@ CDasherWindow::~CDasherWindow() {
 
 void CDasherWindow::Main() {
   // TODO: Sort this sort ofthing out, figure out how it fits into ATL etc.
-
+  // This function is not called by anybody...
 #ifndef _WIN32_WCE
 	DASHER_ASSERT_VALIDPTR_RW(m_pDasher);
 #endif
 
 	m_pDasher->Main();
-	Sleep(50); // limits framerate to 50fps
+	Sleep(50); // limits framerate to 20fps
 }
 
 int CDasherWindow::MessageLoop() {
@@ -358,6 +364,14 @@ LRESULT CDasherWindow::OnCommand(UINT message, WPARAM wParam, LPARAM lParam, BOO
   case ID_HELP_DASHERTUTORIAL:
     m_pGameModeHelper = new CGameModeHelper(m_pDasher);
     return 0;
+  case ID_GAMEMODE:
+    m_pDasher->GameMessageIn(m_pGameGroup->IsWindowVisible()?
+      (GameMode::GAME_MESSAGE_GAME_OFF) : (GameMode::GAME_MESSAGE_GAME_ON),
+      NULL);
+    m_pGameGroup->ShowWindow(m_pGameGroup->IsWindowVisible()?SW_HIDE:SW_SHOW);
+    m_pEdit->Clear();
+    Layout();
+    return 0;
   case IDM_EXIT:
     DestroyWindow();
     return 0;
@@ -408,7 +422,8 @@ LRESULT CDasherWindow::OnCommand(UINT message, WPARAM wParam, LPARAM lParam, BOO
     return 0;
   case ID_IMPORT_TRAINFILE:
     // TODO: Fix dummy arguments
-    m_pDasher->TrainFile(m_pEdit->Import(),0,0);
+	  // Game temp comment for compiling
+    //m_pDasher->TrainFile(m_pEdit->Import(),0,0);
     return 0;
   default:
     return DefWindowProc(message, wParam, lParam);
@@ -436,14 +451,20 @@ LRESULT CDasherWindow::OnDasherEvent(UINT message, WPARAM wParam, LPARAM lParam,
       
       switch (pEvt->m_iEditType) {
       case 1:
-	m_pGameModeHelper->Output(pEvt->m_sText);
-	break;
+	      m_pGameModeHelper->Output(pEvt->m_sText);
+	      break;
       case 2:
-	m_pGameModeHelper->Delete(pEvt->m_sText.size());
-	break;
+	      m_pGameModeHelper->Delete(pEvt->m_sText.size());
+	      break;
       }
     }
     break;
+  case EV_EDIT_CONTEXT:
+    {
+      Dasher::CEditContextEvent *pEvt = static_cast< Dasher::CEditContextEvent * >(pEvent);
+      m_pDasher->SetContext(m_pEdit->get_context(pEvt->m_iOffset, pEvt->m_iLength));
+    }
+    break;
   default:
     break;
   }
@@ -454,6 +475,12 @@ LRESULT CDasherWindow::OnDasherEvent(UINT message, WPARAM wParam, LPARAM lParam,
   return 0;
 }
 
+LRESULT CDasherWindow::OnGameMessage(UINT message, WPARAM wParam, LPARAM lParam, BOOL& bHandled) {
+  m_pGameGroup->Message(static_cast<int>(wParam), reinterpret_cast<const void*>(lParam));
+  bHandled=true;
+	return 0;
+}
+
 LRESULT CDasherWindow::OnDasherFocus(UINT message, WPARAM wParam, LPARAM lParam, BOOL& bHandled) {
 	::SetFocus(m_pEdit->GetHwnd());
 
@@ -471,7 +498,7 @@ LRESULT CDasherWindow::OnDestroy(UINT message, WPARAM wParam, LPARAM lParam, BOO
 #ifndef _WIN32_WCE
 LRESULT CDasherWindow::OnGetMinMaxInfo(UINT message, WPARAM wParam, LPARAM lParam, BOOL& bHandled) {
 	// not yet created
-	if (m_pToolbar == 0 || m_pSplitter == 0 || m_pSlidebar == 0)
+	if (m_pToolbar == 0 || m_pSplitter == 0 || m_pSpeedAlphabetBar == 0)
 		return 0;
 
 	bHandled = TRUE;
@@ -481,10 +508,10 @@ LRESULT CDasherWindow::OnGetMinMaxInfo(UINT message, WPARAM wParam, LPARAM lPara
     // Set minimum height:
     if(m_pAppSettings->GetBoolParameter(APP_BP_SHOW_TOOLBAR))
       lppt[3].y = m_pToolbar->GetHeight() + m_pSplitter->GetPos()
-        + m_pSplitter->GetHeight() + m_pSlidebar->GetHeight() + GetSystemMetrics(SM_CYEDGE) * 10;
+        + m_pSplitter->GetHeight() + m_pSpeedAlphabetBar->GetHeight() + GetSystemMetrics(SM_CYEDGE) * 10;
     else
       lppt[3].y = m_pSplitter->GetPos()
-        + m_pSplitter->GetHeight() + m_pSlidebar->GetHeight() + GetSystemMetrics(SM_CYEDGE) * 10;
+        + m_pSplitter->GetHeight() + m_pSpeedAlphabetBar->GetHeight() + GetSystemMetrics(SM_CYEDGE) * 10;
 
 	return 0;
 }
@@ -521,15 +548,21 @@ LRESULT CDasherWindow::OnSetFocus(UINT message, WPARAM wParam, LPARAM lParam, BO
 }
 
 LRESULT CDasherWindow::OnOther(UINT message, WPARAM wParam, LPARAM lParam, BOOL& bHandled) {
+	// A switch statement would be preferable, except the message ids are
+  // not constant-expressions since they are provided by the system at
+  // runtime.
   if (message == WM_DASHER_EVENT)
     return OnDasherEvent( message, wParam, lParam, bHandled);
   else if (message == WM_DASHER_FOCUS)
     return OnDasherFocus(message, wParam, lParam, bHandled);
+  else if (message == WM_DASHER_GAME_MESSAGE)
+    return OnGameMessage(message, wParam, lParam, bHandled);
   else if (message == DASHER_SHOW_PREFS) {
 #ifndef _WIN32_WCE
     CPrefs Prefs(m_hWnd, m_pDasher, m_pAppSettings);
 #endif
   }
+  
   return 0;
 }
 
@@ -538,7 +571,7 @@ void CDasherWindow::Layout() {
   
   // Set up the window properties
 #ifndef _WIN32_WCE
-  if((iStyle == 1) || (iStyle == 2)) {
+  if((iStyle == APP_STYLE_COMPOSE) || (iStyle == APP_STYLE_DIRECT)) {
     SetWindowLong(GWL_EXSTYLE, GetWindowLong(GWL_EXSTYLE) | WS_EX_NOACTIVATE | WS_EX_APPWINDOW);
     SetWindowPos(HWND_TOPMOST, 0, 0, 0, 0, SWP_NOMOVE | SWP_NOSIZE);
   }
@@ -550,32 +583,41 @@ void CDasherWindow::Layout() {
 
   // Now do the actual layout
 
-  bool bHorizontal(iStyle == 1); 
-  bool bShowEdit(iStyle != 2);
+  bool bHorizontal(iStyle == APP_STYLE_COMPOSE); 
+  bool bShowEdit(iStyle != APP_STYLE_DIRECT);
 
+  // Get the width of the window
   RECT ClientRect;
   GetClientRect( &ClientRect);
   const int Width = ClientRect.right;
   const int Height = ClientRect.bottom;
 
+  // Get the height of the toolbar widget
   int ToolbarHeight;
   if(m_pToolbar && m_pAppSettings->GetBoolParameter(APP_BP_SHOW_TOOLBAR))
     ToolbarHeight = m_pToolbar->GetHeight();
   else
     ToolbarHeight = 0;
-  int CurY = ToolbarHeight;
 
-  int SlidebarHeight;
-  if(m_pSlidebar != 0)
-    SlidebarHeight = m_pSlidebar->GetHeight();
+  // Get the height of the control bar at the bottom of the screen
+  int SpeedAlphabetHeight;
+  if(m_pSpeedAlphabetBar != 0)
+    SpeedAlphabetHeight = m_pSpeedAlphabetBar->GetHeight();
   else
-    SlidebarHeight = 0;
-  int MaxCanvas = Height - SlidebarHeight;
+    SpeedAlphabetHeight = 0;
+
+  int GameGroupHeight = m_pGameGroup->GetHeight();
+  int GameGroupWidth = m_pGameGroup->GetWidth();
+  int GameLabelHeight = m_pGameGroup->GetLabelHeight();
+
+  int MaxCanvas = Height - SpeedAlphabetHeight*2;
+  int CurY = ToolbarHeight;
 
   if(m_pSplitter) {
     int SplitterPos = m_pSplitter->GetPos();
     int SplitterHeight = m_pSplitter->GetHeight();
-    SplitterPos = max(CurY + 2 * SplitterHeight, SplitterPos);
+    //SplitterPos = max(CurY + 2 * SplitterHeight, SplitterPos);
+    SplitterPos = max(CurY + GameGroupHeight, SplitterPos);
     SplitterPos = min(SplitterPos, MaxCanvas - 3 * SplitterHeight);
     m_pSplitter->Move(SplitterPos, Width);
 
@@ -590,9 +632,13 @@ void CDasherWindow::Layout() {
       if(bShowEdit) {
         m_pEdit->ShowWindow(SW_SHOW);
         m_pSplitter->ShowWindow(SW_SHOW);
+        m_pGameGroup->MoveWindow(0,CurY,Width,GameGroupHeight);
 
         if(m_pEdit)
-          m_pEdit->Move(2, CurY + 2, Width - 4, SplitterPos - CurY - 2);
+        {
+          //m_pEdit->Move(2, CurY+2, Width, SplitterPos - CurY-2);
+          m_pEdit->Move(0, CurY+GameLabelHeight, Width-GameGroupWidth, SplitterPos - CurY-GameLabelHeight);
+        }
 
         CurY = SplitterPos + SplitterHeight;
       }
@@ -601,23 +647,27 @@ void CDasherWindow::Layout() {
         m_pSplitter->ShowWindow(SW_HIDE);
       }
 
-      int CanvasHeight = Height - CurY - SlidebarHeight - GetSystemMetrics(SM_CYEDGE);
- 
+      int CanvasHeight = Height - CurY - SpeedAlphabetHeight ;
+      //- GetSystemMetrics(SM_CYEDGE);
+      
+      // Put the DasherControl in the correct place...
       if(m_pDasher)
-        m_pDasher->Move(2, CurY+2, Width-4, CanvasHeight-2);
-
-      if(m_pSlidebar)
-        m_pSlidebar->MoveWindow(2, Height - SlidebarHeight, Width-4, SlidebarHeight);
-     }
-
+        m_pDasher->Move(0, CurY, Width, CanvasHeight-5);
+        //m_pDasher->Move(2, CurY+2, Width-4, CanvasHeight-2);
+      
+      // ...with the bottom bar just below it.
+      if(m_pSpeedAlphabetBar)
+        m_pSpeedAlphabetBar->MoveWindow(0, Height - SpeedAlphabetHeight, Width, SpeedAlphabetHeight);
+      //  m_pSlidebar->MoveWindow(2, Height - SlidebarHeight, Width-4, SlidebarHeight);
 
+    }
   }
 }
 
 #ifndef _WIN32_WCE
 void CDasherWindow::HandleWinEvent(HWINEVENTHOOK hWinEventHook, DWORD event, HWND hwnd, LONG idObject, LONG idChild, DWORD dwEventThread, DWORD dwmsEventTime) {
   // Ignore events if not in direct mode
-  if(m_pAppSettings && (m_pAppSettings->GetLongParameter(APP_LP_STYLE) != 2))
+  if(m_pAppSettings && (m_pAppSettings->GetLongParameter(APP_LP_STYLE) != APP_STYLE_DIRECT))
     return;
 
   // For now assume all events are focus changes, so reset the buffer
